@@ -21,8 +21,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#pragma interface
-
 #include "FolderList.h"
 #include "PrefDialog.h"
 
@@ -53,21 +51,6 @@ protected:
 	Glib::RefPtr<Gtk::ToggleAction> actionViewRead;
 	Glib::RefPtr<Gtk::ToggleAction> actionViewImportant;
 
-	/*
-	Gtk::Menu editMenu;
-	Gtk::Menu helpMenu;
-
-	Gtk::Widget* saveMenuItem;
-	Gtk::Widget* saveasMenuItem;
-	Gtk::Widget* undoMenuItem;
-	Gtk::Widget* redoMenuItem;
-	Gtk::Widget* mergeMenuItem;
-	Gtk::Widget* intersectMenuItem;
-	Gtk::Widget* copyToOtherMenuItem;
-	Gtk::Widget* moveToOtherMenuItem;
-	Gtk::Widget* deleteUnselectedMenuItem;
-	*/
-
 	void on_program_exited(int pid, int status);
 
 public:
@@ -76,7 +59,7 @@ public:
 
 	void rescanFolders();
 
-	void on_open_folder(MailFolder folder);
+	void on_open_folder(buffy::MailFolder folder);
 	void on_quit();
 	void on_filter_changed();
 	void do_preferences();
@@ -85,33 +68,6 @@ public:
 
 	/// Set the update timer to the given interval in seconds
 	void set_timer(int interval);
-		
-	//void consume(const MailFolder& folder);
-
-	/*
-	void on_open();
-	void on_open_debtags();
-	void on_save();
-	void on_save_as();
-	void on_undo();
-	void on_redo();
-	void on_merge();
-	void on_intersect();
-	void on_copy_to_other();
-	void on_move_to_other();
-	void on_delete_unselected();
-
-	void on_doc_change();
-	void on_filename_change();
-	void on_selection_change();
-
-	void on_request_tagcoll_change(Tagcoll::TagcollChange<std::string, Tagcoll::Tag> change);
-
-	void on_select_tagset_panel1(Tagcoll::TagSet tagset);
-	void on_select_tagset_panel2(Tagcoll::TagSet tagset);
-
-	void on_addButton_clicked();
-	*/
 };
 
 // vim:set ts=4 sw=4:
