@@ -1,3 +1,21 @@
+/*
+ * Copyright (C) 2003--2010  Enrico Zini <enrico@debian.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 #pragma implementation
 
 #include "config.h"
@@ -5,6 +23,7 @@
 #include "Environment.h"
 #include <wibble/exception.h>
 
+#include <cstdlib>
 #include <sys/types.h>  // fork, stat, utimes
 #include <unistd.h>     // fork, execl, isatty, pipe
 #include <sys/stat.h>   // stat
@@ -80,7 +99,7 @@ Environment::Environment()
 
 void Environment::enumerateFolders(MailFolderConsumer& cons)
 {
-	vector<string> locations = config().locations().get();
+	vector<string> locations = config().locations();
 	for (vector<string>::const_iterator i = locations.begin();
 			i != locations.end(); i++)
 	{
