@@ -2,7 +2,7 @@
 #define DEBTAGS_ENVIRONMENT_H
 
 /*
- * Copyright (C) 2003--2008  Enrico Zini <enrico@debian.org>
+ * Copyright (C) 2003--2010  Enrico Zini <enrico@debian.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,13 +29,11 @@ class Environment
 {
 public:
 	// void child_exited(int pid, int status);
-	typedef SigC::Signal2<void, int, int> type_signal_child_exit;
+	typedef sigc::signal2<void, int, int> type_signal_child_exit;
 
 protected:
 	static Environment* instance;
 
-	xmlpp::Document* doc_conf;
-
 	// True when operations should be verbose
 	bool _verbose;
 
