@@ -4,7 +4,7 @@
 /*
  * Folder list widget
  *
- * Copyright (C) 2003  Enrico Zini <enrico@debian.org>
+ * Copyright (C) 2003--2010  Enrico Zini <enrico@debian.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 #pragma interface
 
-#include <buffy/MailFolder.h>
+#include <buffy/mailfolder.h>
 
 #include <sigc++/sigc++.h>
 #include <gtkmm/scrolledwindow.h>
@@ -45,7 +45,7 @@ namespace config {
 class FolderList : public Gtk::VBox, public buffy::MailFolderConsumer
 {
 public:
-	typedef SigC::Signal1<void, buffy::MailFolder> type_signal_open_folder;
+	typedef sigc::signal1<void, buffy::MailFolder> type_signal_open_folder;
 
 protected:
 	Gtk::TreeView folderList;
