@@ -1,7 +1,7 @@
 /*
  * buffy - Mailbox watcher
  *
- * Copyright (C) 2003  Enrico Zini
+ * Copyright (C) 2003--2008  Enrico Zini <enrico@enricozini.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,47 +28,50 @@
 #endif
 
 #include "Environment.h"
-#include "CommandlineParser.h"
 #include "BuffyWindow.h"
 #include <wibble/exception.h>
+#include <wibble/commandline/parser.h>
 
 #include <gtkmm/main.h>
 
 using namespace std;
 using namespace wibble;
+using namespace wibble::commandline;
+
+struct Options : public StandardParserWithManpage
+{
+	BoolOption* verbose;
+	BoolOption* debug;
+
+	Options() : StandardParserWithManpage("buffy", PACKAGE_VERSION, 1, PACKAGE_BUGREPORT)
+	{
+		usage = "";
+		description =
+			"Mail folder monitor.\n"
+			"Monitor new and unread messages in a collection of mail folders.";
+		longDescription =
+			"Buffy is a program that displays a compact summary of your mail folders, and "
+			"allows to invoke a command (usually a mail reader) on them.  It is written "
+			"with the intent of being a handy everyday tool for people handling large "
+			"volumes of mail.  For mutt users, this can be a nice front-end to supplement "
+			"the simple built-in folder browser when one has many folders to keep track of.";
+		verbose = add<BoolOption>("verbose", 0, "verbose", "", "enable verbose output");
+		debug = add<BoolOption>("debug", 0, "debug", "", "enable debugging output (includes verbose output)");
+	}
+};
 
 int main(int argc, char* argv[])
 {
+	Options opts;
 	try {
-		CommandlineParser opts(APPNAME, "[options] [file1|-]",
-				"Mail folder monitor.\n"
-				"Monitor new and unread messages in a collection of mail folders.\n");
-		opts.add("version", 0, "version", "print the program version, then exit");
-		opts.add("verbose", 0, "verbose", "enable verbose output");
-		opts.add("debug", 0, "debug", "enable debugging output (including verbose output)");
-
-		// Process the commandline
-		if (!opts.parse(argc, const_cast<const char**&>(argv)))
-		{
-			opts.printHelp();
-			return 1;
-		}
-		if (opts.get("help").defined())
-		{
-			opts.printHelp();
+		if (opts.parse(argc, (const char**)argv))
 			return 0;
-		}
 
 		Environment::init();
 		
-		if (opts.get("version").defined())
-		{
-			printf("%s ver." PACKAGE_VERSION "\n", APPNAME);
-			return 0;
-		}		
-		if (opts.get("verbose").defined())
+		if (opts.verbose->boolValue())
 			Environment::get().verbose(true);
-		if (opts.get("debug").defined())
+		if (opts.debug->boolValue())
 			Environment::get().debug(true);
 
 		Gtk::Main app(argc, argv);
@@ -85,10 +88,12 @@ int main(int argc, char* argv[])
 		Environment::get().config().save();
 		
 		return 0;
-	}
-	catch (wibble::exception::Generic& e)
-	{
-		fatal_error("%s: %s\n", e.type(), e.fullInfo().c_str());
+	} catch (wibble::exception::BadOption& e) {
+		cerr << e.desc() << endl;
+		opts.outputHelp(cerr);
+		return 1;
+	} catch (std::exception& e) {
+		cerr << e.what() << endl;
 		return 1;
 	}
 }
